#!/bin/sh

if [ ! -x /opt/lsb-tet3-lite/bin/tcc ]
then
	printf "tcc not found, aborting\n"
	exit 1
fi

TET_ROOT=`pwd`
TET_PATH=/opt/lsb-tet3-lite
MANPATH=$MANPATH:$TET_PATH/man
PATH=$TET_PATH/bin:$TET_ROOT/xts5/bin:$PATH
export PATH MANPATH TET_ROOT

# use TMPDIR/tet_tmp_dir if TMPDIR defined, otherwise ~/tmp/tet_tmp_dir
if [ -n "$TMPDIR" ];then
  TET_TMP_DIR="$TMPDIR/tet_tmp_dir"
else
  TET_TMP_DIR="$HOME/tmp/tet_tmp_dir"
fi

if [ ! -d "$TET_TMP_DIR" ];then
  install -d $TET_TMP_DIR
fi

# same deal for our execute dir
if [ -n "$TMPDIR" ];then
  TEXEC_DIR="$TMPDIR/xts5"
else
  TEXEC_DIR="$HOME/tmp/xts5"
fi

if [ ! -d "$TEXEC_DIR" ];then
  install -d $TEXEC_DIR
fi

# Template marker for version in journal file
BUILD_VERSION="5.1.5-0.20190330.47.lsb5 (i386)"

config_param() { 
DEFAULT=`grep "^$1=" xts5/tetexec.cfg | cut -d= -f2`

printf "$2 ("
if [ -n "$DEFAULT" ];
then
  printf "$DEFAULT"
fi
printf ")? "
read cmd

if [ -z "$cmd" ]; then
  cmd=$DEFAULT
fi

# Write to temporary file
echo "$1=$cmd" >> /tmp/newparam.$$

}

configure() {
    config_param XT_DISPLAYHOST "Hostname of client for X tests"
    config_param XT_DISPLAY "DISPLAY of the Xvfb (ie., :1.0)"

    echo "VSX_NAME=LSB Certification Version $BUILD_VERSION" >> /tmp/newparam.$$

    mv $TET_ROOT/xts5/tetexec.cfg $TET_ROOT/xts5/tetexec.cfg.old
    cat $TET_ROOT/xts5/tetexec.cfg.old | $TET_ROOT/xts5/bin/editcfg.sh /tmp/newparam.$$ > $TET_ROOT/xts5/tetexec.cfg
}

# Configure the test suites
if [ ! -f lock/.configured ]; then
    configure
    touch lock/.configured
fi

XT_DISPLAY=`grep '^XT_DISPLAY=' xts5/tetexec.cfg | cut -f 2 -d=`
TEST_DISPLAY="`expr $XT_DISPLAY : '.*\(:[0-9][0-9]*\.[0-9][0-9]*\)'`" 
XT_FONTPATH=`grep '^XT_FONTPATH=' xts5/tetexec.cfg | cut -f 2 -d= `

pkill Xvfb
(/opt/lsb/bin/Xvfb -render -screen 0 1024x768x16 $TEST_DISPLAY -ac +bs -kb -fp $XT_FONTPATH &)
echo "Starting X Virtual Frame Buffer"; sleep 20
export DISPLAY=$TEST_DISPLAY

# Test that test fonts are installed
echo "Testing whether the test fonts are installed .... "
type -p xlsfonts > /dev/null
if [ $? -eq 0 ]; then
  xlsfonts xtfont0 | grep xtfont0 
  if [ $? -ne 0 ]; then
    echo 'Could not find xtfont0. xlsfonts xtfont? should list xtfont0..xtfont6'
    echo 'Aborting tests'
    exit 1
  fi
else
  echo 'xlsfonts command not found'
fi

cd xts5
find tset -type d | xargs -i install -d $TEXEC_DIR/{} 
for test in `find tset -type f`;do
  tdir=`dirname $test`
  cd $TEXEC_DIR/$tdir
  ln -sf $TET_ROOT/xts5/$test .
  cd $TET_ROOT/xts5
done
cd ..
 
# this test depends on the real hostname of the test machine - create the file for each run
cd $TEXEC_DIR/tset/Xlib17/gtdflt
rm -f .Xdefaults-*
cp -f HstXdefaults .Xdefaults-`hostname`
cd -

# touch our marker so we can find the latest journal
touch $TET_ROOT/.start_test

# bug 2637 - tset/Xlib3/cnnctnnmbr/Test,MTest never finish, end up with
# unusable results - add a timeout of 15mins (-t 900)
cd xts5 && tcc -t 900 -a $TEXEC_DIR -p -e -v DISPLAY=$TEST_DISPLAY xts5 all

# bug 2637 - but now the "system 0" entries in the journal 
# give tjreport fits
JOURNAL=`find $TET_ROOT/xts5/results -cnewer $TET_ROOT/.start_test -name 'journal*'`
grep -q 'system 0' $JOURNAL
if [ "$?" -eq 0 ];then
  echo "corrupt journal, fixing..."
  cp $JOURNAL $JOURNAL.tmp
  grep -v 'system 0' $JOURNAL.tmp > $JOURNAL
  rm -f $JOURNAL.tmp
fi

pkill Xvfb
rm -fr $TEXEC_DIR
rm -fr $TET_TMP_DIR

#EOF
